@@ -3,19 +3,25 @@
 from .data import PersistenceInformation
 
 from .distances import WassersteinDistance
+from .sliced_wasserstein_distance import SlicedWassersteinDistance
+from .multi_scale_kernel import MultiScaleKernel
 
 from .loss import SignatureLoss
 from .loss import SummaryStatisticLoss
 
+from .alpha_complex import AlphaComplex
 from .cubical_complex import CubicalComplex
 from .vietoris_rips_complex import VietorisRipsComplex
 
 
 __all__ = [
+    'AlphaComplex',
     'CubicalComplex',
     'PersistenceInformation',
     'SignatureLoss',
     'SummaryStatisticLoss',
     'VietorisRipsComplex',
     'WassersteinDistance',
+    'SlicedWassersteinDistance',
+    'MultiScaleKernel',
 ]
